/*  An "Expressive" compiler
 *
 *  Program for testing the lexical analyzer
 *  Philippe Altherr, Nikolay Mihaylov
 *
 *  $Id: ScannerTest.java,v 1.6 2003/03/20 12:14:52 mihaylov Exp $
 */

package expressive;

import java.io.InputStream;
import java.io.PrintWriter;

import java_cup.runtime.Symbol;

/**
 * This class tests the lexical analyzer. The program reads
 * the source file and prints in the output file the
 *  sequence of tokens recognized by the lexical analyzer.
 *
 * usage: java expressive.ScannerTest <options> [source_file [output-file]]
 * with the following options:
 *   -debug    Print the debug messages
 *   -? -help  Show this help
 */
public class ScannerTest extends AbstractMain implements Tokens {

    public void run(Global global, InputStream in, PrintWriter out) {
	Scanner scanner = new Scanner(in);
	try {
	    Symbol token = scanner.next_token();
	    while (token.sym != EOF) {
		out.println(toString(token));
		token = scanner.next_token();
	    }
	} catch (java.io.IOException e)
	    { e.printStackTrace(); }
    }

    public static String toString(Symbol token) {
	switch (token.sym) {
	case EOF: return "<EOF>";
	case INT: return "INT(" + token.value + ")";
	case ASSIGN: return ":=";
	case TRUE: return "true";
	// Complete with the rest of the tokens
	default:
	    return "Unknown token: " + token;
	}
    }

    public static void main(String[] args) {
        new ScannerTest().run(args);
    }

}
